/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2022. All rights reserved.
 * Description: MVIZ LOGGER
 * Create: 2020-12-14
 */
#ifndef MVIZ_DEVEL_KIT_LOGGER_H
#define MVIZ_DEVEL_KIT_LOGGER_H

#include <iostream>
#include <iomanip>

#include <sys/time.h>

namespace mviz {
class Logger {
public:
    Logger(const Logger &) = delete;
    Logger &operator =(const Logger &) = delete;

    /*
     * 功能：打印Error信息
     * 输入参数：error-错误信息
     *          file-打印日志的文件名
     *          line-打印日志的行号
     * 输出参数：无
     * 返回值：无
     */
    static inline void Error(const std::string &error) noexcept
    {
        std::cout << LogHeader() << " [Error] [MVIZ_DEVEL_KIT] " << error << std::endl;
    }

    /*
     * 功能：打印Warn信息
     * 输入参数：warn-告警信息
     *          file-打印日志的文件名
     *          line-打印日志的行号
     * 输出参数：无
     * 返回值：无
     */
    static inline void Warn(const std::string& warn) noexcept
    {
        std::cout << LogHeader() << " [Warn] [MVIZ_DEVEL_KIT] " << warn << std::endl;
    }

    /*
     * 功能：打印Info信息
     * 输入参数：info-提示信息
     *          file-打印日志的文件名
     *          line-打印日志的行号
     * 输出参数：无
     * 返回值：无
     */
    static inline void Info(const std::string& info) noexcept
    {
        std::cout << LogHeader() << " [Info] [MVIZ_DEVEL_KIT] " << info << std::endl;
    }

private:
    Logger() = default;
    ~Logger() = default;

    static std::string LogHeader() noexcept
    {
        time_t now = time(nullptr);
        tm dateTime {};
        localtime_r(&now, &dateTime);

        timeval tv {};
        gettimeofday(&tv, nullptr);
        const int32_t microSecondsOfOneMilliSecond = 1000;

        const int32_t startYear = 1900;
        const int32_t formatWidth = 2;
        const int32_t millisecondWidth = 3;

        std::stringstream ss;
        ss << std::to_string(startYear + dateTime.tm_year) << "-"
            << std::setfill('0') << std::setw(formatWidth) << std::to_string(1 + dateTime.tm_mon) << "-"
            << std::setfill('0') << std::setw(formatWidth) << std::to_string(dateTime.tm_mday) << " "
            << std::setfill('0') << std::setw(formatWidth) << std::to_string(dateTime.tm_hour) << ":"
            << std::setfill('0') << std::setw(formatWidth) << std::to_string(dateTime.tm_min) << ":"
            << std::setfill('0') << std::setw(formatWidth) << std::to_string(dateTime.tm_sec) << "."
            << std::setfill('0') << std::setw(millisecondWidth)
            << std::to_string(tv.tv_usec / microSecondsOfOneMilliSecond);

        return ss.str();
    }
};
}

#endif // MVIZ_DEVEL_KIT_LOGGER_H