# Copyright (c) Huawei Technologies Co., Ltd. 2020-2022. All rights reserved.
# Description: mviz_devel_kit模块的入口CMake脚本，主要包含一个target_message_generation函数，
#             用户可通过在自己工程的CMakeLists.txt中调用该函数实现生成ROS的C++代码并调用mviz_devel_kit封装的接口进行自定义数据的发布和订阅
# Create: 2020-12-03
include(ExternalProject)
set(MVIZ_DEVEL_KIT_DIR ${CMAKE_CURRENT_LIST_DIR})

if(${CMAKE_VERSION} VERSION_LESS 3.12.0)
    find_package(PythonInterp REQUIRED)
else()
    find_package(Python3 COMPONENTS Interpreter)
    set(PYTHON_EXECUTABLE ${Python3_EXECUTABLE})
endif()

include(${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/DependencyInfo.cmake)
include(${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/CheckEnv.cmake)
include(${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/InstallDependency.cmake)

function(target_use_mviz_devel_kit)
    set(options "")
    set(oneValueArgs TARGET)
    cmake_parse_arguments(MVIZ "${options}" "${oneValueArgs}" "${multiValueArgs}" ${ARGN})

    if (NOT DEFINED MVIZ_TARGET)
        message(FATAL_ERROR "The TARGET parameter is mandatory.")
    endif ()

    target_compile_definitions(${MVIZ_TARGET}
            PRIVATE
            -DROSCONSOLE_MIN_SEVERITY=ROSCONSOLE_SEVERITY_INFO)

    target_include_directories(${MVIZ_TARGET}
            PRIVATE
            ${CMAKE_CURRENT_SOURCE_DIR}/include
            ${MVIZ_DEVEL_KIT_DIR}/../../../include
            ${MVIZ_DEPENDENCY_INCLUDE})

    add_dependencies(${MVIZ_TARGET} ${MVIZ_DEPENDENCY_TARGETS})
endfunction()

function(target_message_generation)
    set(options "")
    set(oneValueArgs TARGET)
    set(multiValueArgs MESSAGE_DIRS)
    cmake_parse_arguments(MVIZ "${options}" "${oneValueArgs}" "${multiValueArgs}" ${ARGN})

    if (NOT DEFINED MVIZ_TARGET)
        message(FATAL_ERROR "The TARGET parameter is mandatory.")
    endif ()

    if (NOT DEFINED MVIZ_MESSAGE_DIRS)
        message(WARNING "The MESSAGE_DIRS parameter is not set. You are advised to use the target_use_mviz_devel_kit(TARGET ${MVIZ_TARGET}) function if no message needs to be generated.")
    endif ()

    target_use_mviz_devel_kit(TARGET ${MVIZ_TARGET})

    add_custom_target(_mviz_devel_kit_for_${MVIZ_TARGET} ALL
            COMMAND export PYTHONPATH=${python_path_dir} &&
                        ${PYTHON_EXECUTABLE} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/genmsg_by_packages.py
                        -d \"${MVIZ_MESSAGE_DIRS}\"
                        -o ${CMAKE_CURRENT_SOURCE_DIR}
                        -e ${msgs_template_dir}
                        -I std_msgs:${std_msgs_dir}
                        -I geometry_msgs:${geometry_msgs_dir}
                        -I sensor_msgs:${sensor_msgs_dir}
            DEPENDS ${MVIZ_DEPENDENCY_TARGETS})

    add_dependencies(${MVIZ_TARGET} _mviz_devel_kit_for_${MVIZ_TARGET})
endfunction()
