# Copyright (c) Huawei Technologies Co., Ltd. 2020-2022. All rights reserved.
# Description: 检测当前环境中是否已安装ROS，如果已经安装ROS，则直接使用已经安装好的ROS的C++代码生成工具和ROS头文件，
#              如果未安装ROS，则尝试自动从互联网下载
# Create: 2020-12-03

if (EXISTS /opt/ros/${ROS_DISTRO})
    if(NOT DEFINED USE_LOCAL_ROS)
        set(USE_LOCAL_ROS true)
    endif()
endif()

if (USE_LOCAL_ROS)
    set(MVIZ_DEPENDENCY_TARGETS
            _roscpp_serialization)
    set(python_path_dir /opt/ros/${ROS_DISTRO}/lib/python3/dist-packages/)
    set(msgs_template_dir /opt/ros/${ROS_DISTRO}/share/gencpp)
    set(std_msgs_dir /opt/ros/${ROS_DISTRO}/share/std_msgs/msg)
    set(geometry_msgs_dir  /opt/ros/${ROS_DISTRO}/share/geometry_msgs/msg)
    set(sensor_msgs_dir  /opt/ros/${ROS_DISTRO}/share/sensor_msgs/msg)

    set(MVIZ_DEPENDENCY_INCLUDE
            ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization/include
            /opt/ros/${ROS_DISTRO}/include)
else ()
    # 在系统未安装ros，并且有网络连接的情况下，mviz_devel_kit模块会增加_gencpp等依赖，并自动下载和解压到工程的CMake构建目录中
    # 在系统未安装ros，同时无网络链接的情况下，需手动下载各个源码包并指定路径到下载的文件
    set(MVIZ_DEPENDENCY_TARGETS
            _roscpp_serialization
            _gencpp
            _genmsg
            _std_msgs
            _geometry_msgs
            _sensor_msgs
            _roscpp
            _rosconsole
            _rostime
            _cpp_common
            _roscpp_traits)

    set(python_path_dir ${CMAKE_CURRENT_BINARY_DIR}/empy/:${CMAKE_CURRENT_BINARY_DIR}/genmsg/src/:${CMAKE_CURRENT_BINARY_DIR}/gencpp/src/)
    set(msgs_template_dir ${CMAKE_CURRENT_BINARY_DIR}/gencpp/scripts)
    set(std_msgs_dir ${CMAKE_CURRENT_BINARY_DIR}/std_msgs/msg)
    set(geometry_msgs_dir ${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs/msg)
    set(sensor_msgs_dir ${CMAKE_CURRENT_BINARY_DIR}/sensor_msgs/msg)

    set(MVIZ_DEPENDENCY_INCLUDE
            ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization/include
            ${CMAKE_CURRENT_BINARY_DIR}/roscpp/include
            ${CMAKE_CURRENT_BINARY_DIR}/rosconsole/include
            ${CMAKE_CURRENT_BINARY_DIR}/rostime/include
            ${CMAKE_CURRENT_BINARY_DIR}/cpp_common/include
            ${CMAKE_CURRENT_BINARY_DIR}/roscpp_traits/include
            ${CMAKE_CURRENT_BINARY_DIR}/std_msgs/include
            ${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs/include
            ${CMAKE_CURRENT_BINARY_DIR}/sensor_msgs/include)
endif ()