# Copyright (c) Huawei Technologies Co., Ltd. 2020-2021. All rights reserved.
# Description: 执行依赖包的下载或拷贝本地roscpp_serialization头文件并对其进行patch修改
# Create: 2020-12-03

if (USE_LOCAL_ROS)
    add_custom_target(_roscpp_serialization
            COMMAND mkdir -p ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization/include/ros
            COMMAND cp -u /opt/ros/${ROS_DISTRO}/include/ros/serialization.h ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization/include/ros
            COMMAND cp -u /opt/ros/${ROS_DISTRO}/include/ros/roscpp_serialization_macros.h ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization/include/ros
            COMMAND cp -u /opt/ros/${ROS_DISTRO}/include/ros/serialized_message.h ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization/include/ros
            COMMAND bash ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/apply_patch.sh ${CMAKE_CURRENT_BINARY_DIR} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/patch/roscpp_serialization.patch)
else ()
    ExternalProject_Add(_roscpp_serialization
            URL ${roscpp_serialization_URL}
            URL_HASH SHA256=${roscpp_serialization_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/roscpp_serialization
            PATCH_COMMAND     bash ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/apply_patch.sh ${CMAKE_CURRENT_BINARY_DIR} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/patch/roscpp_serialization.patch
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_roscpp
            URL ${roscpp_URL}
            URL_HASH SHA256=${roscpp_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/roscpp
            PATCH_COMMAND     bash ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/apply_patch.sh ${CMAKE_CURRENT_BINARY_DIR} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/patch/roscpp.patch
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_rosconsole
            URL ${rosconsole_URL}
            URL_HASH SHA256=${rosconsole_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/rosconsole
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_rostime
            URL ${rostime_URL}
            URL_HASH SHA256=${rostime_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/rostime
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_cpp_common
            URL ${cpp_common_URL}
            URL_HASH SHA256=${cpp_common_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/cpp_common
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_roscpp_traits
            URL ${roscpp_traits_URL}
            URL_HASH SHA256=${roscpp_traits_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/roscpp_traits
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_empy
            URL ${empy_URL}
            URL_HASH SHA256=${empy_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/empy
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   "")

    ExternalProject_Add(_gencpp
            URL ${gencpp_URL}
            URL_HASH SHA256=${gencpp_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/gencpp
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   ""
            DEPENDS _empy)

    ExternalProject_Add(_genmsg
            URL ${genmsg_URL}
            URL_HASH SHA256=${genmsg_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/genmsg
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     ""
            INSTALL_COMMAND   ""
            DEPENDS _empy)

    ExternalProject_Add(_std_msgs
            URL ${std_msgs_URL}
            URL_HASH SHA256=${std_msgs_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/std_msgs
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     export PYTHONPATH=${python_path_dir} &&
                                ${PYTHON_EXECUTABLE} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/mviz_genmsg.py
                                -m ${CMAKE_CURRENT_BINARY_DIR}/std_msgs/msg
                                -p std_msgs
                                -o ${CMAKE_CURRENT_BINARY_DIR}/std_msgs/include/std_msgs
                                -e ${CMAKE_CURRENT_BINARY_DIR}/gencpp/scripts
                                -I std_msgs:${CMAKE_CURRENT_BINARY_DIR}/std_msgs/msg
            INSTALL_COMMAND   ""
            DEPENDS _gencpp _genmsg)

    ExternalProject_Add(_geometry_msgs
            URL ${geometry_msgs_URL}
            URL_HASH SHA256=${geometry_msgs_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     export PYTHONPATH=${python_path_dir} &&
                                ${PYTHON_EXECUTABLE} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/mviz_genmsg.py
                                -m ${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs/msg
                                -p geometry_msgs
                                -o ${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs/include/geometry_msgs
                                -e ${CMAKE_CURRENT_BINARY_DIR}/gencpp/scripts
                                -I std_msgs:${CMAKE_CURRENT_BINARY_DIR}/std_msgs/msg
                                -I geometry_msgs:${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs/msg
            INSTALL_COMMAND   ""
            DEPENDS _gencpp _genmsg _std_msgs)

    ExternalProject_Add(_sensor_msgs
            URL ${sensor_msgs_URL}
            URL_HASH SHA256=${sensor_msgs_URL_HASH}
            SOURCE_DIR ${CMAKE_CURRENT_BINARY_DIR}/sensor_msgs
            CONFIGURE_COMMAND ""
            BUILD_COMMAND     export PYTHONPATH=${python_path_dir} &&
                                ${PYTHON_EXECUTABLE} ${MVIZ_DEVEL_KIT_DIR}/mviz_devel_kit/scripts/mviz_genmsg.py
                                -m ${CMAKE_CURRENT_BINARY_DIR}/sensor_msgs/msg
                                -p sensor_msgs
                                -o ${CMAKE_CURRENT_BINARY_DIR}/sensor_msgs/include/sensor_msgs
                                -e ${CMAKE_CURRENT_BINARY_DIR}/gencpp/scripts
                                -I std_msgs:${CMAKE_CURRENT_BINARY_DIR}/std_msgs/msg
                                -I geometry_msgs:${CMAKE_CURRENT_BINARY_DIR}/geometry_msgs/msg
                                -I sensor_msgs:${CMAKE_CURRENT_BINARY_DIR}/sensor_msgs/msg
            INSTALL_COMMAND   ""
            DEPENDS _gencpp _genmsg _std_msgs _geometry_msgs)
endif()
